Choices objects
===============

This is a much clearer way to specify choices for fields in models and forms.
Current documentation can be found at the `dj.choices PyPI page
<http://pypi.python.org/pypi/dj.choices>`_.

.. note::

  The legacy ``lck.django.choices`` namespace will be removed in ``lck.django``
  1.0.
